Downloading REDCap Source Code
==============================

REDCap code is available only through Vanderbilt University.

Possession and use of REDCap code and workflow methodology is strictly
limited to institutions and organizations who have finalized an End-User
License Agreement with Vanderbilt University.

https://redcap.vanderbilt.edu/consortium/

Long Term Support URLs
----------------------

* https://iwg.devguard.com/trac/redcap/browser/zips_redcap/6.0.5/redcap6.0.5.zip
* https://iwg.devguard.com/trac/redcap/browser/zips_redcap/6.0.5/redcap6.0.5_upgrade.zip

